@@ -79,12 +79,12 @@ void ttc_terminate()
 guint8* ttc_get_translation_table (const gchar* language)
 {
 	
-	gchar* 	key = NULL;
-	guint8*	value = NULL;
+	gchar*	key 	= NULL;
+	guint8*	value  	= NULL;
 	
-	gchar* 	fn;
-	gchar* dir_fn = NULL;
-	FILE* 		fp;
+	gchar*	fn	= NULL;
+	gchar*	dir_fn 	= NULL;
+	FILE* 	fp	= NULL;
 	
 	/* search the key in the table first */
 	value = (guint8*) g_hash_table_lookup (TranslationTableCache, language);
@@ -94,8 +94,7 @@ guint8* ttc_get_translation_table (const gchar* language)
 		/* the table is not in the cache, try to load it from the TT file */
 			
 		/* derive the TT file name from the language name */
-		fn = g_strdup_printf ("%s.A2B", language);
-		g_strup(fn);
+		fn = g_strdup_printf ("%s.a2b", language);
 		/* open the file */
 	        if (g_file_test (fn, G_FILE_TEST_EXISTS)) 
 		{
@@ -320,39 +319,6 @@ void brl_disp_load_translation_table (BRL_DISP *brl_disp, gchar* language)
 {
 	
 	brl_disp->TranslationTable = ttc_get_translation_table (language);
-	
-#if 0	
-	gchar* fn;
-	FILE* fp;
-	
-	/* !!! TBR !!! use a cache (i.e. HashTable?) */
-			
-	g_free (brl_disp->Language);
-	g_free (brl_disp->TranslationTable);									/* !!! TBR !!! */
-	brl_disp->TranslationTable = g_malloc0(TT_SIZE);			/* !!! TBR !!! */
-	
-	/* !!! TBI !!! verify if the correrct TT is not already in palce */
-	
-	/* copy the language string */
-	brl_disp->Language = g_strdup (language);
-	
-	/* create the actual file name */
-	fn = g_strdup_printf ("%s.A2B", language);
-	g_strup(fn);
-	
-	/* open the file */
-	fp = fopen (fn, "rb");
-	if (fp)
-	{		
-		/* load translation table in memory */
-		fread (brl_disp->TranslationTable, 1, TT_SIZE, fp);		
-
-		fclose (fp);	
-	}	
-	g_free (fn);
-	
-#endif	
-
 }
 
 
@@ -413,32 +379,6 @@ void brl_out_load_translation_table (BRL_OUT *brl_out, gchar* language)
 {
 	
 	brl_out->TranslationTable = ttc_get_translation_table (language);
-
-#if 0	
-	gchar* fn;
-	FILE* fp;
-	
-	/* !!! TBR !!! use a cache (i.e. HashTable?) */
-			
-	g_free (brl_out->Language);
-	brl_out->Language = g_strdup (language);
-	
-	/* create the actual file name */
-	fn = g_strdup_printf ("%s.A2B", language);
-	g_strup(fn);
-	
-	/* open the file */
-	fp = fopen (fn, "rb");
-	if (fp)
-	{		
-		/* load translation table in memory */
-		fread (brl_out->TranslationTable, 1, TT_SIZE, fp);		
-
-		fclose (fp);	
-	}
-	
-	g_free (fn);
-#endif
 }
 
 void brl_out_set_brl_style (BRL_OUT *brl_out, gchar* style)
