@@ -124,10 +124,10 @@ brltty_brl_glib_cb (GIOChannel *source, GIOCondition condition, gpointer data)
     BRAILLE_EVENT_CODE 	bec;
     BRAILLE_EVENT_DATA 	bed;
 
-    while (brlapi_readCommand (0, &keypress ) == 1) 
+    while (brlapi_readCommand (0, &keypress) == 1) 
     {
 	/* TODO: Find a better way to map brltty commands to gnopernicus keys. */
-	switch (keypress & ~VAL_SWITCHMASK) 
+	switch (keypress & ~VAL_TOGGLE_MASK) 
 	{
 	    case CMD_LNUP:
     		sprintf(&dd.key_codes[0], "DK00");
@@ -179,11 +179,7 @@ brltty_brl_glib_cb (GIOChannel *source, GIOCondition condition, gpointer data)
 			ClientCallback (bec, &bed);
 			break;
 		    default:
-			sprintf(&dd.key_codes[0], "DK%02d", keypress);
-			fprintf(stderr,"default: Sending %s\n", dd.key_codes);
-			bec = bec_key_codes;
-			bed.KeyCodes = dd.key_codes;						
-			ClientCallback (bec, &bed);
+			fprintf(stderr,"BRLTTY command code not bound to Gnopernicus key code: 0X%04X\n", keypress);
 			break;
     		}
     		break;
@@ -193,6 +189,39 @@ brltty_brl_glib_cb (GIOChannel *source, GIOCondition condition, gpointer data)
     return TRUE;
 }
 
+static void
+ignoreBlock (int block)
+{
+    brlapi_ignoreKeys(block, block|VAL_ARG_MASK);
+}
+
+static void
+ignoreInput (int block)
+{
+    static const int flags[] = {
+                0 |         0 |        0 |           0,
+                0 |         0 |        0 | VPC_CONTROL,
+                0 |         0 | VPC_META |           0,
+                0 |         0 | VPC_META | VPC_CONTROL,
+                0 | VPC_UPPER |        0 |           0,
+                0 | VPC_UPPER |        0 | VPC_CONTROL,
+                0 | VPC_UPPER | VPC_META |           0,
+                0 | VPC_UPPER | VPC_META | VPC_CONTROL,
+        VPC_SHIFT |         0 |        0 |           0,
+        VPC_SHIFT |         0 |        0 | VPC_CONTROL,
+        VPC_SHIFT |         0 | VPC_META |           0,
+        VPC_SHIFT |         0 | VPC_META | VPC_CONTROL,
+        VPC_SHIFT | VPC_UPPER |        0 |           0,
+        VPC_SHIFT | VPC_UPPER |        0 | VPC_CONTROL,
+        VPC_SHIFT | VPC_UPPER | VPC_META |           0,
+        VPC_SHIFT | VPC_UPPER | VPC_META | VPC_CONTROL
+    };
+    const int *flag = flags + (sizeof(flags) / sizeof(*flag));
+    do {
+        ignoreBlock(block | *--flag);
+    } while (*flag);
+}
+
 int
 brltty_brl_open_device (char* 			DeviceName, 
 			short 			Port,
@@ -240,6 +269,10 @@ brltty_brl_open_device (char* 			DeviceName,
     */
     brlapi_getTty (0, BRLCOMMANDS, NULL);
 
+    ignoreInput(VAL_PASSCHAR);
+    ignoreInput(VAL_PASSDOTS);
+    ignoreBlock(VAL_PASSKEY);
+
     return 1;
 }
 
