@@ -545,6 +545,8 @@ brlmon_get_string_with_default (const gchar *key, gchar *def)
  *
  * return: modetype.
 **/
+
+/*FIXME when brlmon will be rewritten.*/
 ModeType
 brlmon_get_mode_type_from_string (const gchar *mode)
 {
@@ -555,9 +557,9 @@ brlmon_get_mode_type_from_string (const gchar *mode)
     
     if (!strcmp (tmp, MODE_NORMAL_STRING))  modetype = MODE_NORMAL;
 	else
-    if (!strcmp (tmp, MODE_BRAILLE_STRING)) modetype = MODE_BRAILLE;
+    if (!strcmp (tmp, MODE_BRAILLE_STRING)) modetype = MODE_NORMAL;
 	else
-    if (!strcmp (tmp, MODE_DUAL_STRING))    modetype = MODE_DUAL;
+    if (!strcmp (tmp, MODE_DUAL_STRING))    modetype = MODE_NORMAL;
 	else
     {
 	sru_warning (_("Invalid modetype: %s."), mode);		    
@@ -568,6 +570,7 @@ brlmon_get_mode_type_from_string (const gchar *mode)
     
     return modetype;
 }
+/*FIXME END*/
 
 /**
  * brlmon_get_font_size
@@ -1294,7 +1297,7 @@ brlmon_create_text_area (gint line, gint column)
         line	= DEFAULT_LINE;
 	brlmon_set_int (line,  BRAILLE_MONITOR_LINE_GCONF_KEY);    
 	brlmon_set_int (column,   BRAILLE_MONITOR_COLUMN_GCONF_KEY);    
-	sru_message (_("To many cells on display. [Max %d]"), PANEL_LENGHT / 2);
+	sru_message (_("Too many cells on display. [Max %d]"), PANEL_LENGHT / 2);
         sru_message (_("Load default display size. Line: %d Column: %d."), line, column);
     }
             
