@@ -35,11 +35,11 @@
 #define NO_ITEM_IN_STATUS_CELL 		2
 
 
-struct {
+static struct {
     KeyItem 		*current_keyitem;
     GtkTreeIter 	current_iter;
     gboolean		current_is_new;
-} current_item;
+} brl_current_item;
 
 enum
 {
@@ -327,10 +327,22 @@ static void
 brlui_braille_device_combo_changed (GtkWidget *entry,
 				    gpointer  user_data)
 {
+#if 0 /* remove when it need to select the tty number */
     gchar   *port_text = NULL;
     gdouble min_val, max_val;
+#endif 
+    gboolean 	sensitivity;
     sru_return_if_fail (braille_setting);    
     
+    if (!strcmp (BRLTTY, gtk_entry_get_text (GTK_ENTRY (entry))))
+	sensitivity = FALSE;
+    else
+	sensitivity = TRUE;
+	
+    gtk_widget_set_sensitive (GTK_WIDGET (lb_port), sensitivity);
+    gtk_widget_set_sensitive (GTK_WIDGET (sp_port), sensitivity);
+    
+#if 0    /* remove when it need to select the tty number */
     if (!strcmp (BRLTTY, gtk_entry_get_text (GTK_ENTRY (entry))))
     {
 	min_val   = (gdouble)MIN_TTY_CONSOL_NO;
@@ -348,6 +360,7 @@ brlui_braille_device_combo_changed (GtkWidget *entry,
     gtk_spin_button_set_range (GTK_SPIN_BUTTON (sp_port), min_val, max_val);
     gtk_label_set_text (GTK_LABEL (lb_port), port_text);
     gtk_label_set_use_underline (GTK_LABEL (lb_port), TRUE);
+#endif
 }
 
 static void
@@ -357,7 +370,7 @@ brlui_settings_response_braille_device (GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -462,10 +475,15 @@ brlui_translation_table_value_add_to_widgets (Braille *braille_setting)
     GtkTreeIter      iter;
     gboolean 	     valid;
     gint 	     l_iter;
+    
 
     sru_return_val_if_fail (w_translation_table, FALSE);
     sru_return_val_if_fail (braille_setting, FALSE);
     
+    g_free (braille_setting->translation_table);
+    braille_setting->translation_table = 
+	    brlconf_translation_table_get ();
+    
     model 	  = gtk_tree_view_get_model ( GTK_TREE_VIEW (tv_translation_table));
     selection     = gtk_tree_view_get_selection ( GTK_TREE_VIEW (tv_translation_table));
     
@@ -570,7 +588,7 @@ brlui_settings_response_translation_table ( GtkDialog *dialog,
 
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -663,7 +681,7 @@ brlui_settings_response_braille_style ( GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -754,7 +772,7 @@ brlui_settings_response_cursor_settings (GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -854,7 +872,7 @@ brlui_settings_response_attribute_settings (GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -988,7 +1006,7 @@ brlui_settings_response_braille_fill_char ( GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -1093,7 +1111,7 @@ brlui_settings_response_status_cell (GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -1164,8 +1182,8 @@ brlui_selection_add_func (GtkTreeModel 	*model,
 	    
 	if (cmd_function[pos].descr)
 	{
-	    (current_item.current_keyitem)->command_list = 
-		g_slist_prepend ((current_item.current_keyitem)->command_list, 
+	    (brl_current_item.current_keyitem)->command_list = 
+		g_slist_prepend ((brl_current_item.current_keyitem)->command_list, 
 				g_strdup (cmd_function [pos].name));
 	}
 	
@@ -1201,7 +1219,7 @@ brlui_add_modify_ok (void)
 	return FALSE;
     }
     
-    if (current_item.current_is_new)
+    if (brl_current_item.current_is_new)
     {
 	if (!cmdconf_check_if_item_exist (braille_keys_list, key))
 	{
@@ -1213,11 +1231,11 @@ brlui_add_modify_ok (void)
 	    braille_keys_list = 
 		g_slist_prepend (braille_keys_list , new_item);		    
 		
-	    current_item.current_keyitem = new_item;
-	    (current_item.current_keyitem)->command_list = NULL;
-	    (current_item.current_keyitem)->commands = NULL;
+	    brl_current_item.current_keyitem = new_item;
+	    (brl_current_item.current_keyitem)->command_list = NULL;
+	    (brl_current_item.current_keyitem)->commands = NULL;
     	    gtk_list_store_append (GTK_LIST_STORE (model), 
-				    &current_item.current_iter);
+				    &brl_current_item.current_iter);
 	}
 	else
 	{
@@ -1226,25 +1244,25 @@ brlui_add_modify_ok (void)
 	}
     }
         
-    (current_item.current_keyitem)->command_list =
-	cmdconf_free_list_and_data ((current_item.current_keyitem)->command_list);
+    (brl_current_item.current_keyitem)->command_list =
+	cmdconf_free_list_and_data ((brl_current_item.current_keyitem)->command_list);
 
     gtk_tree_selection_selected_foreach (selection, 
     					brlui_selection_add_func, 
 					NULL);
 					
-    (current_item.current_keyitem)->command_list = 
-        cmdconf_check_integrity ( (current_item.current_keyitem)->command_list);
+    (brl_current_item.current_keyitem)->command_list = 
+        cmdconf_check_integrity ( (brl_current_item.current_keyitem)->command_list);
 
-    txt = cmdconf_create_view_string ((current_item.current_keyitem)->command_list);
+    txt = cmdconf_create_view_string ((brl_current_item.current_keyitem)->command_list);
         
     if (!txt)
 	return FALSE;
 	
-    (current_item.current_keyitem)->commands = txt;
-    gtk_list_store_set (GTK_LIST_STORE (model), &current_item.current_iter, 
-			KEYS_COLUMN, 	(current_item.current_keyitem)->key_code,
-		    	FUNC_COLUMN, 	_((current_item.current_keyitem)->commands),
+    (brl_current_item.current_keyitem)->commands = txt;
+    gtk_list_store_set (GTK_LIST_STORE (model), &brl_current_item.current_iter, 
+			KEYS_COLUMN, 	(brl_current_item.current_keyitem)->key_code,
+		    	FUNC_COLUMN, 	_((brl_current_item.current_keyitem)->commands),
 		    	-1);
     return TRUE;
 }
@@ -1266,15 +1284,15 @@ brlui_treeviews_set_current_value (void)
     
     gtk_tree_selection_unselect_all (selection);	
             
-    if (!current_item.current_is_new)
+    if (!brl_current_item.current_is_new)
     {
-        if (!(current_item.current_keyitem)->key_code) 
+        if (!(brl_current_item.current_keyitem)->key_code) 
 	return;
 
-	if (strcmp ((current_item.current_keyitem)->key_code, BLANK))
+	if (strcmp ((brl_current_item.current_keyitem)->key_code, BLANK))
 	{	
 	GSList *elem = NULL;
-	for (elem = (current_item.current_keyitem)->command_list ; elem ; elem = elem->next)
+	for (elem = (brl_current_item.current_keyitem)->command_list ; elem ; elem = elem->next)
 	{
 	    GtkTreeIter iter;
 	    gboolean valid;
@@ -1305,12 +1323,12 @@ brlui_treeviews_set_current_value (void)
 	}
 	}
 	gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (cb_braille_key)->entry), 
-			    (current_item.current_keyitem)->key_code);
+			    (brl_current_item.current_keyitem)->key_code);
     }
     else
         gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (cb_braille_key)->entry),  "");
 	
-    gtk_widget_set_sensitive (cb_braille_key, current_item.current_is_new);
+    gtk_widget_set_sensitive (cb_braille_key, brl_current_item.current_is_new);
 }
 
 static void
@@ -1320,7 +1338,7 @@ brlui_response_add_modify_event (GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -1574,7 +1592,7 @@ brlui_settings_response_braille_key_mapping (GtkDialog *dialog,
     
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
     
@@ -1595,7 +1613,7 @@ static void
 brlui_braille_keys_add_clicked(GtkWidget *button,
 	        	       gpointer user_data)
 {
-    current_item.current_is_new = TRUE;
+    brl_current_item.current_is_new = TRUE;
     brlui_load_braille_mapping_add_modify ();
 }
 
@@ -1641,9 +1659,9 @@ brlui_braille_keys_modify (void)
 
     sru_return_if_fail (new_code);
     
-    current_item.current_keyitem = new_code;
-    current_item.current_iter = iter;
-    current_item.current_is_new = FALSE;
+    brl_current_item.current_keyitem = new_code;
+    brl_current_item.current_iter = iter;
+    brl_current_item.current_is_new = FALSE;
     brlui_load_braille_mapping_add_modify ();
 }
 
