@@ -140,6 +140,7 @@ static gboolean gn_braille_disable = FALSE;
 static gboolean gn_speech_disable  = FALSE;
 static gboolean gn_magnifier_disable = FALSE;
 static gboolean gn_braille_monitor_disable = FALSE;
+static gboolean gn_login = FALSE;
 
 static gchar   *gn_braille_device = NULL;
 static gint     gn_braille_port = -1;
@@ -228,6 +229,15 @@ struct poptOption poptopt[] =
 	 "disable braille monitor service", 
 	 NULL
 	},
+	{
+	 "login", 
+	 'l', 
+	 POPT_ARG_NONE, 
+	 &gn_login, 	
+	 0, 
+	 "Used at login time", 
+	 NULL
+	},
 	{
 	 "braille-port", 
 	 'p',   
@@ -326,12 +336,15 @@ main (gint argc,gchar *argv[])
     }
     
     gn_gnopernicus_wait_to_core ();
-	            
-    if (!gn_check_accessibility_key ())
+    
+    if (!gn_login)
     {
-	sru_warning (_("Exit gnopernicus."));
-	srcore_exit_all (TRUE);
-	return FALSE;
+	if (!gn_check_accessibility_key ())
+	{
+	    sru_warning (_("Exit gnopernicus."));
+	    srcore_exit_all (TRUE);
+	    return FALSE;
+	}
     }
 
     if (!gn_init ())
@@ -432,6 +445,7 @@ gn_run_with_parameters (void)
 	index++;
     }
     
+
     if (gn_braille_monitor_disable)    
     {
     	gn_argv[index] = g_strdup ("--disable-braille-monitor");
