@@ -61,9 +61,8 @@ magconf_gconf_client_init (void)
 
     if (error != NULL)
     {
-	sru_warning (_("magconf:Failed to set notify:\n"));
-	sru_warning (_("Recomanded to delete ~/.gconf and ~/.gconfd directories"));
-	g_error_free(error);
+	sru_warning (_(error->message));
+	g_error_free (error);
 	error = NULL;
 	return FALSE;
     }
@@ -118,7 +117,7 @@ magconf_setting_clone (Magnifier *magnifier)
     value->cursor_state	= magnifier->cursor_state;
     value->cursor_name	= g_strdup (magnifier->cursor_name);
     value->cursor_size	= magnifier->cursor_size;
-    value->cursor_mag   = magnifier->cursor_mag;
+    value->cursor_scale = magnifier->cursor_scale;
     value->cursor_color = magnifier->cursor_color;
     
     value->crosswire 	= magnifier->crosswire;
@@ -139,6 +138,8 @@ magconf_setting_init (const gchar *id,
 		      gboolean set_struct)
 {
     Magnifier *value = NULL;
+    gint size_x, size_y;
+    
     value = magconf_setting_new ();
     
     sru_assert (value);
@@ -147,14 +148,18 @@ magconf_setting_init (const gchar *id,
     else	
 	value->id	= g_strdup (DEFAULT_MAGNIFIER_ID);
 	
+    magconf_get_display_size (&size_x, &size_y);
+	
 	
     value->source 	= g_strdup (DEFAULT_MAGNIFIER_SOURCE);
     value->target 	= g_strdup (DEFAULT_MAGNIFIER_TARGET);
-    (value->zp).left	= DEFAULT_MAGNIFIER_ZP_LEFT;
+    (value->zp).left	= size_x / 2;
     (value->zp).top	= DEFAULT_MAGNIFIER_ZP_TOP;
+    (value->zp).height	= size_y;
+    (value->zp).width	= size_x;
+
     (value->zp).height	= DEFAULT_MAGNIFIER_ZP_HEIGHT;
     (value->zp).width	= DEFAULT_MAGNIFIER_ZP_WIDTH;
-    
     value->zoomfactorx	= DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
     value->zoomfactory	= DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
     value->zoomfactor_lock	= DEFAULT_MAGNIFIER_ZOOM_FACTOR_LOCK;
@@ -170,7 +175,7 @@ magconf_setting_init (const gchar *id,
     value->cursor_state	= DEFAULT_MAGNIFIER_CURSOR;
     value->cursor_name	= g_strdup (DEFAULT_MAGNIFIER_CURSOR_NAME);
     value->cursor_size	= DEFAULT_MAGNIFIER_CURSOR_SIZE;
-    value->cursor_mag   = DEFAULT_MAGNIFIER_CURSOR_MAG;
+    value->cursor_scale = DEFAULT_MAGNIFIER_CURSOR_SCALE;
     value->cursor_color = DEFAULT_MAGNIFIER_CURSOR_COLOR;
     
     value->crosswire 	= DEFAULT_MAGNIFIER_CROSSWIRE;
@@ -181,6 +186,9 @@ magconf_setting_init (const gchar *id,
     value->mouse_tracking = g_strdup (DEFAULT_MAGNIFIER_MOUSE_TRACKING);
     value->tracking  	  = g_strdup (DEFAULT_MAGNIFIER_TRACKING);
     
+    value->alignment_x   = g_strdup (DEFAULT_MAGNIFIER_ALIGNMENT_X);
+    value->alignment_y   = g_strdup (DEFAULT_MAGNIFIER_ALIGNMENT_Y);
+        
     if (!set_struct)
 	return value;
     
@@ -215,7 +223,7 @@ magconf_setting_new (void)
     new_magnifier = ( Magnifier * ) g_new0 ( Magnifier, 1);
     
     if (!new_magnifier) 
-	sru_error (_("Unable to allocate memory"));
+	sru_error (_("Unable to allocate memory."));
     
     return new_magnifier ;
 }
@@ -232,6 +240,8 @@ magconf_setting_free (Magnifier* magnifier)
     g_free (magnifier->cursor_name);
     g_free (magnifier->smoothing);
     g_free (magnifier->mouse_tracking);
+    g_free (magnifier->alignment_x);
+    g_free (magnifier->alignment_y);
     g_free (magnifier->tracking);
     g_free (magnifier->source);
     g_free (magnifier->target);
@@ -266,7 +276,8 @@ magconf_load_zoomer_from_schema (const gchar *schema,
 {
     Magnifier *magnifier = NULL;
     gchar *path = NULL;
-
+    gint size_x, size_y;
+    
     sru_return_val_if_fail (schema, NULL);    
     sru_return_val_if_fail (zoomer, NULL);    
     
@@ -274,6 +285,8 @@ magconf_load_zoomer_from_schema (const gchar *schema,
     
     sru_assert (magnifier);
     
+    magconf_get_display_size (&size_x, &size_y);
+    
     path = g_strdup_printf ("%s/%s/%s", 
 			    CONFIG_PATH MAGNIFIER_PATH, 
 			    schema, 
@@ -296,7 +309,7 @@ magconf_load_zoomer_from_schema (const gchar *schema,
     (magnifier->zp).left 	= gnopiconf_get_int_from_section_with_default (
 								path, 	
 								MAGNIFIER_ZP_LEFT, 	
-								DEFAULT_MAGNIFIER_ZP_LEFT);
+								size_x / 2);
     (magnifier->zp).top 	= gnopiconf_get_int_from_section_with_default (
 								path, 	
 								MAGNIFIER_ZP_TOP, 	
@@ -304,11 +317,11 @@ magconf_load_zoomer_from_schema (const gchar *schema,
     (magnifier->zp).width 	= gnopiconf_get_int_from_section_with_default (
 								path, 	
 								MAGNIFIER_ZP_WIDTH, 	
-								DEFAULT_MAGNIFIER_ZP_WIDTH);
+								size_x);
     (magnifier->zp).height 	= gnopiconf_get_int_from_section_with_default (
 								path, 	
 								MAGNIFIER_ZP_HEIGHT, 	
-								DEFAULT_MAGNIFIER_ZP_HEIGHT);
+								size_y);
     magnifier->visible 		= gnopiconf_get_bool_from_section_with_default (
 								path,	
 								MAGNIFIER_VISIBLE, 	
@@ -350,10 +363,11 @@ magconf_load_zoomer_from_schema (const gchar *schema,
 								path, 	
 								MAGNIFIER_CURSOR_SIZE, 	
 								DEFAULT_MAGNIFIER_CURSOR_SIZE);
-    magnifier->cursor_mag   	= gnopiconf_get_bool_from_section_with_default (
+
+    magnifier->cursor_scale   	= gnopiconf_get_bool_from_section_with_default (
 								path, 	
-								MAGNIFIER_CURSOR_MAG, 	
-								DEFAULT_MAGNIFIER_CURSOR_MAG);
+								MAGNIFIER_CURSOR_SCALE, 	
+								DEFAULT_MAGNIFIER_CURSOR_SCALE);
     magnifier->cursor_color   	= gnopiconf_get_int_from_section_with_default (
 								path, 	
 								MAGNIFIER_CURSOR_COLOR, 	
@@ -387,6 +401,15 @@ magconf_load_zoomer_from_schema (const gchar *schema,
 								path, 	
 								MAGNIFIER_MOUSE_TRACKING,	
 								DEFAULT_MAGNIFIER_MOUSE_TRACKING);    
+    magnifier->alignment_x 	= gnopiconf_get_string_from_section_with_default (
+								path,
+								MAGNIFIER_ALIGNMENT_X,
+								DEFAULT_MAGNIFIER_ALIGNMENT_X);
+    magnifier->alignment_y 	= gnopiconf_get_string_from_section_with_default (
+								path,
+								MAGNIFIER_ALIGNMENT_Y,
+								DEFAULT_MAGNIFIER_ALIGNMENT_Y);
+
     magnifier->tracking  	= gnopiconf_get_string_from_section_with_default (
 								path, 	
 								MAGNIFIER_TRACKING,	
@@ -552,7 +575,7 @@ magconf_save_zoomer_in_schema (const gchar *schema,
 
     gnopiconf_set_int_in_section (magnifier->border_width, path, 	
 				    MAGNIFIER_BORDER_WIDTH);
-    gnopiconf_set_int_in_section (magnifier->border_color, path, 	
+    gnopiconf_set_int_in_section ((gint)magnifier->border_color, path, 	
 				    MAGNIFIER_BORDER_COLOR);
 			
     gnopiconf_set_bool_in_section (magnifier->cursor_state, path, 	
@@ -561,16 +584,17 @@ magconf_save_zoomer_in_schema (const gchar *schema,
 				    MAGNIFIER_CURSOR_NAME);
     gnopiconf_set_int_in_section (magnifier->cursor_size, path, 	
 				    MAGNIFIER_CURSOR_SIZE);
-    gnopiconf_set_bool_in_section (magnifier->cursor_mag, path, 	
-				    MAGNIFIER_CURSOR_MAG);
-    gnopiconf_set_int_in_section (magnifier->cursor_color, path, 	
+    gnopiconf_set_bool_in_section (magnifier->cursor_scale, path, 	
+				    MAGNIFIER_CURSOR_SCALE);
+
+    gnopiconf_set_int_in_section ((gint)magnifier->cursor_color, path, 	
 				    MAGNIFIER_CURSOR_COLOR);
 
     gnopiconf_set_string_in_section (magnifier->smoothing, path, 	
 				    MAGNIFIER_SMOOTHING);
     gnopiconf_set_bool_in_section (magnifier->crosswire_clip, path, 
 				    MAGNIFIER_CROSSWIRE_CLIP);
-    gnopiconf_set_int_in_section (magnifier->crosswire_color, path, 
+    gnopiconf_set_int_in_section ((gint)magnifier->crosswire_color, path, 
 				    MAGNIFIER_CROSSWIRE_COLOR);
     gnopiconf_set_int_in_section (magnifier->crosswire_size, path, 
 				    MAGNIFIER_CROSSWIRE_SIZE);
@@ -579,6 +603,10 @@ magconf_save_zoomer_in_schema (const gchar *schema,
 			
     gnopiconf_set_string_in_section (magnifier->mouse_tracking, path, 
 					MAGNIFIER_MOUSE_TRACKING);
+    gnopiconf_set_string_in_section (magnifier->alignment_x, path, 
+					MAGNIFIER_ALIGNMENT_X);
+    gnopiconf_set_string_in_section (magnifier->alignment_y, path, 
+					MAGNIFIER_ALIGNMENT_Y);
     gnopiconf_set_string_in_section (magnifier->tracking, path, 
 					MAGNIFIER_TRACKING);
     
@@ -591,13 +619,8 @@ void
 magconf_get_display_size (gint *size_x,
 			  gint *size_y)
 {
-    *size_x = gnopiconf_get_int_from_section_with_default (CONFIG_PATH MAGNIFIER_CONFIG_PATH, 	
-							   MAGNIFIER_DISPLAY_SIZE_X, 	
-							   DEFAULT_MAGNIFIER_DISPLAY_SIZE_X);
-
-    *size_y = gnopiconf_get_int_from_section_with_default (CONFIG_PATH MAGNIFIER_CONFIG_PATH, 	
-							   MAGNIFIER_DISPLAY_SIZE_Y, 	
-							   DEFAULT_MAGNIFIER_DISPLAY_SIZE_Y);
+    *size_x = gdk_screen_width () - 1;
+    *size_y = gdk_screen_height () - 1;
 }
 
 void
@@ -615,15 +638,15 @@ magconf_changes_cb			(GConfClient	*client,
 	if (!entry->value)
 	    return;
 		
-	sru_debug ("magconf:magconf_changes_cb:Entry key:%s",gconf_entry_get_key(entry));
-	sru_debug ("magconf:magconf_changes_cb:Entry value type:%i",entry->value->type);
+	sru_debug ("magconf_changes_cb:Entry key:%s",gconf_entry_get_key(entry));
+	sru_debug ("magconf_changes_cb:Entry value type:%i",entry->value->type);
 	switch(entry->value->type)
 	{
-    	    case GCONF_VALUE_INT:    sru_debug ("magconf:magconf_changes_cb:Entry value:%i",gconf_value_get_int(entry->value));break;
-    	    case GCONF_VALUE_FLOAT:  sru_debug ("magconf:magconf_changes_cb:Entry value:%f",gconf_value_get_float(entry->value));break;
-    	    case GCONF_VALUE_STRING: sru_debug ("magconf:magconf_changes_cb:Entry value:%s",gconf_value_get_string(entry->value));break;
-    	    case GCONF_VALUE_BOOL:   sru_debug ("magconf:magconf_changes_cb:Entry value:%i",gconf_value_get_bool(entry->value));break;
-	    default: sru_debug ("magconf:magconf_changes_cb:Other Entry value:");break;	
+    	    case GCONF_VALUE_INT:    sru_debug ("magconf_changes_cb:Entry value:%i",gconf_value_get_int(entry->value));break;
+    	    case GCONF_VALUE_FLOAT:  sru_debug ("magconf_changes_cb:Entry value:%f",gconf_value_get_float(entry->value));break;
+    	    case GCONF_VALUE_STRING: sru_debug ("magconf_changes_cb:Entry value:%s",gconf_value_get_string(entry->value));break;
+    	    case GCONF_VALUE_BOOL:   sru_debug ("magconf_changes_cb:Entry value:%i",gconf_value_get_bool(entry->value));break;
+	    default: sru_debug ("magconf_changes_cb:Other Entry value:");break;	
 	}
 
 	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_ZOOM_FACTOR_LOCK) == 0)
@@ -726,17 +749,17 @@ magconf_changes_cb			(GConfClient	*client,
 	    }
 	}
 	else    
-	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_CURSOR_MAG) == 0)
+	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_CURSOR_SCALE) == 0)
 	{
 	    if (entry->value->type == GCONF_VALUE_BOOL)
 	    {
-	        magnifier_setting->cursor_mag = 
+	        magnifier_setting->cursor_scale = 
 		    gconf_value_get_bool (entry->value);
 		magui_set_cursor_mag (magnifier_setting);
 	    }
 	}
 	else
-	if (strcmp (key,CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_CURSOR_COLOR) == 0)
+	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_CURSOR_COLOR) == 0)
 	{
 	    if (entry->value->type == GCONF_VALUE_INT)
 	    {
@@ -827,5 +850,15 @@ magconf_changes_cb			(GConfClient	*client,
 		magui_set_mouse_tracking (magnifier_setting);
 	    }
 	}
-
+/*	if (strcmp (key, CONFIG_PATH MAGNIFIER_PATH MAGNIFIER_SCHEMA1 MAGNIFIER_FOCUS_TRACKING) == 0)
+	{
+	    if (entry->value->type == GCONF_VALUE_STRING)
+	    {
+		g_free (magnifier_setting->focus_tracking);
+		magnifier_setting->focus_tracking = 
+		    g_strdup (gconf_value_get_string (entry->value));
+		magui_set_focus_tracking (magnifier_setting);
+	    }
+	}
+*/
 }
