@@ -236,7 +236,7 @@ magui_magnification_settings_response (GtkDialog *dialog,
     else
     if (response_id == GTK_RESPONSE_HELP) 
     {
-    	gn_load_help ("gnopernicus-magnifier-settings");
+    	gn_load_help ("gnopernicus-magnifier-prefs");
 	return;
     }
     else
@@ -966,7 +966,7 @@ magui_magnification_options_save_changed (void)
 	    {
 		g_free (magnifier_setting->mouse_tracking);
 		magnifier_setting->mouse_tracking = 
-		    g_strdup (magui_mouse_tracking[iter].key);
+		    g_strdup (magui_mouse_tracking[iter].description);
 		break;
 	    }
 	}
@@ -1015,7 +1015,7 @@ magui_magnification_options_response (GtkDialog *dialog,
     else
     if (response_id == GTK_RESPONSE_HELP) 
     {
-    	gn_load_help ("gnopernicus-magnifier-settings");
+    	gn_load_help ("gnopernicus-magnifier-prefs");
 	return;
     }
     else
@@ -1217,9 +1217,9 @@ magui_mouse_tracking_value_changed(GtkWidget *widget,
 	
     for (iter = 0; iter < G_N_ELEMENTS (magui_mouse_tracking); iter++)
     {
-	if (strcmp (magui_mouse_tracking[iter].description, tmp) == 0)
+	if (strcmp (_(magui_mouse_tracking[iter].description), tmp) == 0)
 	{
-	    if (strcmp (magui_mouse_tracking[iter].description,
+	    if (strcmp (magui_mouse_tracking[iter].key,
 			magnifier_setting->mouse_tracking))
 	    {
 		    g_free (magnifier_setting->mouse_tracking);
@@ -1248,20 +1248,24 @@ magui_smoothing_value_changed(GtkWidget *widget,
 				     (cb_smoothing)->entry
 				     ));
 
-    if (tmp && strcmp (magnifier_setting->smoothing, tmp))
+    if (tmp)
     {
 	for (iter = 0; iter < G_N_ELEMENTS (magui_smoothing); iter++)
 	{
-	    if (strcmp (magui_smoothing[iter].description, tmp) == 0)
-	    {
-		g_free (magnifier_setting->smoothing);
-		magnifier_setting->smoothing = 
-		    g_strdup (magui_smoothing[iter].key);
-		magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+	    if (strcmp (_(magui_smoothing[iter].description), tmp) == 0)
+	    {	
+		if (magui_smoothing[iter].key != magnifier_setting->smoothing)
+		{
+		    g_free (magnifier_setting->smoothing);
+		    magnifier_setting->smoothing = 
+			g_strdup (magui_smoothing[iter].key);
+		    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
 					    GCONF_VALUE_STRING,
 					    MAGNIFIER_SMOOTHING,
 					    (gpointer)magnifier_setting->smoothing);
-		break;
+		
+		    break;
+		}
 	    }
 	}
     }	 
@@ -1751,63 +1755,65 @@ magui_set_zoomfactor_lock(Magnifier *magnifier_setting)
 
 gboolean
 magui_set_smoothing (Magnifier *magnifier_setting)
-{    
+{
+    gchar *smoothing;
+
     sru_return_val_if_fail (magnifier_setting, FALSE);
+
     if (!w_magnification_options) 
 	return FALSE;
-        
-    if (magnifier_setting->smoothing &&
-	strlen (magnifier_setting->smoothing) != 0)
+
+    smoothing = magnifier_setting->smoothing ? magnifier_setting->smoothing : DEFAULT_MAGNIFIER_SMOOTHING;
+
+    if (smoothing)
     {
 	gint iter;
 	for (iter= 0 ; iter < G_N_ELEMENTS (magui_smoothing) ; ++iter)
 	{
-	    if (!strcmp (magui_smoothing[iter].key, 
-			 magnifier_setting->smoothing))
+	    if (!strcmp (magui_smoothing[iter].key, smoothing))
 	    {
 		gtk_entry_set_text  (GTK_ENTRY 
 				    (GTK_COMBO 
 				    (cb_smoothing)->entry), 
-				    magui_smoothing[iter].description);
+				    _(magui_smoothing[iter].description));
 		break;
 	    }
 	}
     }
     else
-	gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (cb_smoothing)->entry), 
-			    DEFAULT_MAGNIFIER_SMOOTHING);
-    
+	sru_assert_not_reached ();
+
     return TRUE;
 }
 
 gboolean
 magui_set_mouse_tracking (Magnifier *magnifier_setting)
 {    
+    gchar *tracking;
+    
     sru_return_val_if_fail (magnifier_setting, FALSE);
+    
     if (!w_magnification_options) 
 	return FALSE;
     
-    if (magnifier_setting->mouse_tracking &&
-	strlen (magnifier_setting->mouse_tracking) != 0)
+    tracking = magnifier_setting->mouse_tracking ? magnifier_setting->mouse_tracking : DEFAULT_MAGNIFIER_MOUSE_TRACKING;
+    if (tracking)
     {
 	gint iter;
 	for (iter= 0 ; iter < G_N_ELEMENTS (magui_mouse_tracking) ; ++iter)
 	{
-	    if (!strcmp (magui_mouse_tracking[iter].key, 
-			magnifier_setting->mouse_tracking))
+	    if (!strcmp (magui_mouse_tracking[iter].key, tracking))
 	    {
 		gtk_entry_set_text  (GTK_ENTRY 
 				    (GTK_COMBO 
 				    (cb_mouse_tracking)->entry), 
-				    magui_mouse_tracking[iter].description);
+				    _(magui_mouse_tracking[iter].description));
 		break;
 	    }
 	}
     }
     else
-	gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (cb_mouse_tracking)->entry), 
-			    DEFAULT_MAGNIFIER_MOUSE_TRACKING);
-
+	sru_assert_not_reached ();
     
     return TRUE;
 }
