@@ -32,21 +32,30 @@ typedef GSList  SpeechDriverListType;	    /*data type is Driver*/
 
 typedef struct
 {
-    gchar 	*driver_name;
-    GSList	*driver_voice_list;
+    gchar *voice_name;			/* voice name */
+    gchar *voice_name_descr;		/* voice name what is showed in UI */
+}SpeechVoice;
+
+typedef struct
+{
+    gchar 	*driver_name;		/* driver name */
+    gchar 	*driver_name_descr;	/* driver name what is showed in UI */
+    GSList	*driver_voice_list;	/* list of voices */
 }SpeechDriver;
 
 typedef struct
 {
 /* Gnopernicus speaker(voice) name */
-    gchar 	*gnopernicus_speaker;
+    gchar 	*gnopernicus_speaker; /* gnopernicus voice name */
 
 /* Gnome_speech driver name and the selected speaker(voice)*/
-    gchar 	*driver_name;
-    gchar 	*driver_voice;
+    gchar 	*driver_name;	    /* driver name */
+    gchar 	*driver_name_descr; /* driver name what is showed in UI */
+    gchar 	*voice_name;        /* voice name */
+    gchar 	*voice_name_descr;  /* voice name what is showed in UI */
 
-/* Parameters for driver_voice */
-    gint  	volume;
+/* Parameters for voice_name */
+    gint  	volume;		
     gint  	rate;
     gint  	pitch;        
 }SpeakerSettings;
@@ -97,80 +106,71 @@ gchar*		spconf_spaces_get		(void);
 gchar*		spconf_dictionary_get		(void);
 
 
-SpeechDriver*	spconf_speech_driver_new 	(void);
-void		spconf_speech_driver_free 	(SpeechDriver *sp_driver);
+SpeechDriverListType*	spconf_driver_list_init (void);
+SpeechDriverListType*	spconf_driver_list_free (SpeechDriverListType *driver_list);
 
-SpeechDriverListType*	
-		spconf_driver_list_init 	(void);
-SpeechDriverListType*		
-		spconf_driver_list_free 	(SpeechDriverListType *driver_list);
+gchar*		    spconf_driver_list_voice_descr_name_get (const gchar *name);
+const gchar*	    spconf_driver_list_get_driver_name (SpeechDriverListType *driver_list,
+							const gchar *driver_name_descr);
+const gchar*	    spconf_driver_list_get_driver_name_descr (SpeechDriverListType *driver_list,
+							      const gchar *driver_name);
+const SpeechDriver* spconf_driver_list_get_driver_from_name_descr (SpeechDriverListType *driver_list,
+							     const gchar *driver_name_descr);
+const SpeechDriver* spconf_driver_list_get_driver (SpeechDriverListType *driver_list,
+			    			   const gchar *driver_name);
+const SpeechDriver* spconf_driver_list_get_driver_by_voice (SpeechDriverListType *driver_list,
+			    				    const gchar *voice_name);
+const gchar*	    spconf_driver_list_get_voice_name (SpeechDriverListType *driver_list,
+						       const gchar *driver_name,
+			    			       const gchar *voice_name_descr);
+const SpeechVoice*  spconf_driver_list_get_speech_voice (SpeechDriverListType *driver_list,
+				    			const gchar *driver_name,
+			    	    			const gchar *voice_name_descr);
 
-/* Return NULL if the driver_name not found or error */
-const SpeechDriver*	
-		spconf_driver_list_get_driver 	(SpeechDriverListType *driver_list,
-			    			const gchar *driver_name);
-/* Return NULL if the voice_name not found or error */
-const SpeechDriver*	
-		spconf_driver_list_get_driver_by_voice (SpeechDriverListType *driver_list,
-			    				const gchar *voice_name);
 
-GnopernicusSpeakerListType*
-		spconf_gnopernicus_speakers_clone (GnopernicusSpeakerListType *gs_list);
-GnopernicusSpeakerListType*
-		spconf_gnopernicus_speakers_free (GnopernicusSpeakerListType *gs_list);
-GnopernicusSpeakerListType*
-		spconf_gnopernicus_speakers_add (GnopernicusSpeakerListType *gs_list,
-				    		const gchar *gn_speaker);
-GnopernicusSpeakerListType*
-		spconf_gnopernicus_speakers_remove (GnopernicusSpeakerListType *gs_list,
-						    const gchar *gn_speaker);
-GnopernicusSpeakerListType*
-		spconf_gnopernicus_speakers_find (GnopernicusSpeakerListType *gs_list,
-				    		    const gchar *gn_speaker);
-GnopernicusSpeakerListType*
-		spconf_gnopernicus_speakers_load (GnopernicusSpeakerListType *gs_list,
-						  SpeakerSettingsListType   **speakers_settings);
 
-void		spconf_gnopernicus_speakers_save (GnopernicusSpeakerListType *gs_list);
-void		spconf_gnopernicus_speakers_debug (GnopernicusSpeakerListType *gs_list);
 
-/*---*/
-SpeakerSettings*
-		spconf_speaker_settings_new (void);
-SpeakerSettings*
-		spconf_speaker_settings_free (SpeakerSettings *speaker_settings);
-void		spconf_speaker_settings_save (SpeakerSettings *speaker_settings);
-SpeakerSettings*
-		spconf_speaker_settings_load (const gchar *key);
-SpeakerSettings*
-		spconf_speaker_settings_copy (SpeakerSettings *dest, 
-			    		      SpeakerSettings *source);
-SpeakerSettingsListType*
-		spconf_speaker_settings_list_clone (SpeakerSettingsListType *sp_list);
-SpeakerSettingsListType*
-		spconf_speaker_settings_list_copy (SpeakerSettingsListType *dest, 
-						SpeakerSettingsListType *source);
-SpeakerSettingsListType*
-		spconf_speaker_settings_list_add (SpeakerSettingsListType *sp_list, 
+
+GnopernicusSpeakerListType* spconf_gnopernicus_speakers_clone (GnopernicusSpeakerListType *gs_list);
+GnopernicusSpeakerListType* spconf_gnopernicus_speakers_free (GnopernicusSpeakerListType *gs_list);
+GnopernicusSpeakerListType* spconf_gnopernicus_speakers_add (GnopernicusSpeakerListType *gs_list,
+				    			     const gchar *gn_speaker);
+GnopernicusSpeakerListType* spconf_gnopernicus_speakers_remove (GnopernicusSpeakerListType *gs_list,
+								const gchar *gn_speaker);
+GnopernicusSpeakerListType* spconf_gnopernicus_speakers_find (GnopernicusSpeakerListType *gs_list,
+				    			      const gchar *gn_speaker);
+GnopernicusSpeakerListType* spconf_gnopernicus_speakers_load (GnopernicusSpeakerListType *gs_list,
+							      SpeakerSettingsListType   **speakers_settings);
+void			    spconf_gnopernicus_speakers_save (GnopernicusSpeakerListType *gs_list);
+void			    spconf_gnopernicus_speakers_debug (GnopernicusSpeakerListType *gs_list);
+
+
+
+SpeakerSettings*	spconf_speaker_settings_new (void);
+SpeakerSettings*	spconf_speaker_settings_free (SpeakerSettings *speaker_settings);
+void			spconf_speaker_settings_save (SpeakerSettings *speaker_settings);
+SpeakerSettings*	spconf_speaker_settings_load (const gchar *key);
+SpeakerSettings*	spconf_speaker_settings_copy (SpeakerSettings *dest, 
+			    		    	      SpeakerSettings *source);
+						      
+SpeakerSettingsListType* spconf_speaker_settings_list_clone (SpeakerSettingsListType *sp_list);
+SpeakerSettingsListType* spconf_speaker_settings_list_copy (SpeakerSettingsListType *dest, 
+							    SpeakerSettingsListType *source);
+SpeakerSettingsListType* spconf_speaker_settings_list_add (SpeakerSettingsListType *sp_list, 
 			    			const gchar 	*gn_speaker,
 						const gchar 	*driver_name,
-			    			const gchar 	*driver_voice,
+			    			const gchar 	*voice_name,
 			    			gint  		volume,
 			    			gint  		rate,
 			    			gint  		pitch);
-SpeakerSettingsListType*
-		spconf_speaker_settings_list_remove (SpeakerSettingsListType *sp_list,
-						const gchar *gn_speaker);
-SpeakerSettingsListType*
-		spconf_speaker_settings_list_free (SpeakerSettingsListType *sp_list);    
-SpeakerSettingsListType*
-		spconf_speaker_settings_list_load_default (void);
-SpeakerSettingsListType*
-		spconf_speaker_settings_list_load_from_gconf (GnopernicusSpeakerListType *gnopernicus_speakers);
-void		spconf_speaker_settings_list_save (SpeakerSettingsListType *sp_list);
-SpeakerSettingsListType*
-		spconf_speaker_settings_list_find (SpeakerSettingsListType *sp_list,
-		    	    			   const gchar *gnopernicus_speaker);
+SpeakerSettingsListType* spconf_speaker_settings_list_remove (SpeakerSettingsListType *sp_list,
+							      const gchar *gn_speaker);
+SpeakerSettingsListType* spconf_speaker_settings_list_free (SpeakerSettingsListType *sp_list);    
+SpeakerSettingsListType* spconf_speaker_settings_list_load_default (void);
+SpeakerSettingsListType* spconf_speaker_settings_list_load_from_gconf (GnopernicusSpeakerListType *gnopernicus_speakers);
+void			 spconf_speaker_settings_list_save (SpeakerSettingsListType *sp_list);
+SpeakerSettingsListType* spconf_speaker_settings_list_find (SpeakerSettingsListType *sp_list,
+		    	    				    const gchar *gnopernicus_speaker);
 
 GSList*		spconf_free_slist_with_char_data 	(GSList *list);
 
