@@ -733,10 +733,16 @@ srs_speak (SRSText *srs_text)
 }
 
 void
-srs_call_shut_up ()
+srs_call_shut_up (gint priority, gint preempt)
 {
     if (!cb_support_tranzition)
 	srs_shut_up ();
+    else if (CurrText)
+    {	
+	if (priority > CurrText->priority || 
+	    (priority == CurrText->priority && CurrText->preempt))
+	    srs_shut_up ();
+    }
 }
 
 
