@@ -244,7 +244,8 @@ sr_config_changed_callback (guint cnxn_id,
     SRConfigStructure *SRstruct = NULL;
 
     sru_return_if_fail (entry);
-    sru_return_if_fail (entry->value);
+    if (!entry->value)
+	return;
     
     SRstruct = (SRConfigStructure*) g_new0 (SRConfigStructure, 1);
     sru_assert (SRstruct);
