@@ -134,7 +134,7 @@
 #define DEFAULT_PRESENTATION_ROLE		"generic"
 #define DEFAULT_PRESENTATION_EVENT		"generic"
 
-#define DEFAULT_PRESENTATION_ACTIVE_SETTING_NAME 	"Default"
+#define DEFAULT_PRESENTATION_ACTIVE_SETTING_NAME 	"default"
 /*____________________________< /PRESENTATION_DEFAULTS>___________________________*/
 /*____________________________< MAGNIFIER_DEFAULTS>___________________________*/
 #define MAX_ZOOM_FACTOR_X  			15
@@ -175,8 +175,8 @@
 #define DEFAULT_MAGNIFIER_BORDER_COLOR		0
 
 #define DEFAULT_MAGNIFIER_ID			"generic_zoomer"
-#define DEFAULT_MAGNIFIER_SOURCE		""
-#define DEFAULT_MAGNIFIER_TARGET		""
+#define DEFAULT_MAGNIFIER_SOURCE		":0.0"
+#define DEFAULT_MAGNIFIER_TARGET		":0.0"
 
 #define DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY	2
 #define DEFAULT_MAGNIFIER_ZOOM_FACTOR_LOCK	TRUE
