@@ -44,9 +44,6 @@ extern gboolean src_use_speech;
 extern gboolean src_use_braille;
 extern gboolean src_use_braille_monitor;
 extern gboolean src_enable_format_string;
-extern gchar   *src_braille_translation_table;
-extern gint	src_braille_position_sensor;
-extern gint	src_braille_optical_sensor;
 
 gboolean  src_button_left_pressed   = FALSE;
 gboolean  src_button_middle_pressed = FALSE;
@@ -880,15 +877,15 @@ src_nav_logic (SRNavigationDir dir, const char *missing_node)
 static gboolean src_flat_review_next_line ();
 static gboolean src_flat_review_prev_line ();
 
-extern gint src_braille_offset;
 static gint crt_line = 0;
+static gboolean visited = FALSE;
 
 static gboolean
 src_nav_parent_flat ()
 {
     gboolean rv = FALSE;
     
-    src_braille_offset = 0;
+    src_braille_set_offset (0);
     rv = src_flat_review_prev_line();
 
     return rv;
@@ -913,7 +910,7 @@ src_nav_child_flat ()
 {
     gboolean rv = FALSE;
     
-    src_braille_offset = 0;
+    src_braille_set_offset (0);
     rv = src_flat_review_next_line();
     
     return rv;
@@ -939,8 +936,12 @@ src_nav_next_flat ()
 {
     gboolean rv = FALSE;
     gboolean old_value = src_use_speech;
+    gint offset;
+    
+    offset = src_braille_get_offset ();
+    offset ++;
+    src_braille_set_offset (offset);
     
-    src_braille_offset++;
     src_use_speech = FALSE;
     src_flat_review_line (crt_line);
     src_use_speech = old_value;
@@ -1159,8 +1160,10 @@ src_nav_previous_flat ()
 {
     gboolean rv = FALSE;
     gboolean old_value = src_use_speech;
+    gint offset;
     
-    src_braille_offset = MAX (0, src_braille_offset - 1);
+    offset = src_braille_get_offset ();
+    src_braille_set_offset (MAX (0, offset - 1));
     
     src_use_speech = FALSE;
     src_flat_review_line (crt_line);
@@ -1228,6 +1231,17 @@ src_watch_current ()
     return rv;
 }
 
+static gboolean
+src_unwatch_all ()
+{
+    srl_unwatch_all_objects ();
+    if (src_use_speech)
+    {
+	src_say_message (_("unwatch all objects"));
+    }
+    return TRUE;
+}
+
 static gboolean
 src_nav_caret ()
 {
@@ -2038,8 +2052,9 @@ static gboolean
 src_surroundings_logic ()
 {
     SRObject *parent;
-    gchar *role;
-    gchar *message, *message1, *message2, *message3, *message4, *message5, *message6;
+    gchar *role, *name;
+    gchar *message, *on, *curr_obj_role, *curr_obj_name, *from, *parrent_role, *with, 
+          *no_items, *in, *window, *window_name, *of, *app_name;
     GSList *role_list, *cnt_list;
     GSList *crt, *crt2;
     
@@ -2049,7 +2064,7 @@ src_surroundings_logic ()
     if (!sro_get_sro (src_crt_sro, SR_NAV_PARENT, &parent, SR_NAV_MODE_WINDOW))
 	return FALSE;
     
-    while (!has_parent_stop_role (parent))
+    while (parent && !has_parent_stop_role (parent))
     {
 	SRObject *tmp;
 	if (!sro_get_sro (parent, SR_NAV_PARENT, &tmp, SR_NAV_MODE_WINDOW))
@@ -2061,44 +2076,60 @@ src_surroundings_logic ()
 	sro_release_reference (parent);
 	parent = tmp;
     }
+    
     if (!parent)
 	return FALSE;
     role_list = cnt_list = NULL;
     get_child_stop_role (parent, &role_list, &cnt_list);
-
     
-    message1 = NULL;
-    message2 = NULL;
     if (sro_get_role_name (src_crt_sro, &role, SR_INDEX_CONTAINER))
-    {
-	message1 = src_xml_make_part ("TEXT", src_speech_get_voice ("system"), _("on a"));
-    	message2 = src_xml_make_part ("TEXT", src_speech_get_voice ("role"), (gchar *)src_pres_get_role_name_for_speech (role));
+    {  
+	on = src_xml_make_part ("TEXT", src_speech_get_voice ("system"), _("on"));
+    	curr_obj_role = src_xml_make_part ("TEXT", src_speech_get_voice ("role"), (gchar *)src_pres_get_role_name_for_speech (role));
 	SR_freeString (role);
     }
+    else
+    {
+	on = g_strdup ("");
+	curr_obj_role = g_strdup ("");
+    }
+    
+    if (sro_get_name (src_crt_sro, &name, SR_INDEX_CONTAINER))
+    {
+	curr_obj_name = src_xml_make_part ("TEXT", src_speech_get_voice ("name"), (gchar*)name);
+	SR_freeString (name);
+    }
+    else
+    {
+	curr_obj_name = g_strdup ("");
+    }
     
-    message3 = NULL;
-    message4 = NULL;
-    message5 = NULL;
     if (sro_get_role_name (parent, &role, SR_INDEX_CONTAINER))
     {
-	message3 = src_xml_make_part ("TEXT", src_speech_get_voice ("system"), _("from a"));
-	message4 = src_xml_make_part ("TEXT", src_speech_get_voice ("role"), (gchar *)src_pres_get_role_name_for_speech (role));
-	message5 = src_xml_make_part ("TEXT", src_speech_get_voice ("system"), _("with"));
+	from = src_xml_make_part ("TEXT", src_speech_get_voice ("system"), _("from a"));
+	parrent_role = src_xml_make_part ("TEXT", src_speech_get_voice ("role"), (gchar *)src_pres_get_role_name_for_speech (role));
+	with = src_xml_make_part ("TEXT", src_speech_get_voice ("system"), _("with"));
 	SR_freeString (role);
     }
+    else
+    {
+	from = g_strdup ("");
+	parrent_role = g_strdup ("");
+	with = g_strdup ("");
+    }
     
-    message6 = g_strdup ("");
+    no_items = g_strdup ("");
     for (crt = role_list, crt2 = cnt_list; crt; crt = crt->next, crt2 = crt2->next)
     {
     	gchar *tmp, *tmp2, *tmp3, *tmp4;
 	gchar cnt[10];
 	
-	tmp = message6;
+	tmp = no_items;
 	sprintf (cnt, "%d", GPOINTER_TO_INT (crt2->data));
 	tmp2 = src_xml_make_part ("TEXT", src_speech_get_voice ("childcount"), cnt);
 	tmp3 = src_xml_make_part ("TEXT", src_speech_get_voice ("role"), (gchar *)src_pres_get_role_name_for_speech ((gchar*) crt->data));
 	tmp4 = src_xml_make_part ("TEXT", src_speech_get_voice ("system"), ngettext ("item", "items", GPOINTER_TO_INT (crt2->data)));
-	message6 = g_strconcat (message6, tmp2, tmp3, tmp4, NULL);
+	no_items = g_strconcat (no_items, tmp2, tmp3, tmp4, NULL);
 	
 	g_free (tmp);
 	g_free (tmp2);
@@ -2106,11 +2137,47 @@ src_surroundings_logic ()
 	g_free (tmp4);
     }
 
+    if (sro_get_window_name (src_crt_sro, &role, &name, SR_INDEX_CONTAINER))
+    {
+	in = src_xml_make_part ("TEXT", src_speech_get_voice ("system"), _("in a"));
+	window = src_xml_make_part ("TEXT", src_speech_get_voice ("role"), (gchar*)role);
+	if (name)
+	    name = g_strconcat (_("named "), name, NULL);
+	else
+	    name = g_strdup (_("with no name"));    
+	window_name = src_xml_make_part ("TEXT", src_speech_get_voice ("name"), (gchar*)name);
+	SR_freeString (role);
+	SR_freeString (name);
+    }   
+    else
+    {
+	in = g_strdup ("");
+	window = g_strdup ("");
+	window_name = g_strdup ("");  
+    }
+	
+    if (sro_get_app_name (src_crt_sro, &name, SR_INDEX_CONTAINER))
+    {
+	of = src_xml_make_part ("TEXT", src_speech_get_voice ("system"), _("of application"));
+	app_name = src_xml_make_part ("TEXT", src_speech_get_voice ("name"), (gchar*)name);
+	SR_freeString (name);
+    } 
+    else
+    {
+	of = g_strdup ("");
+	app_name = g_strdup ("");
+    }
+    
+    
     
     message = NULL;
-    if (message1 || message2 || message3 || message4 || message5 || message6)
-	message = g_strconcat (message1, message2, message3, 
-			    message4, message5, message6, NULL);
+    if (on || curr_obj_role || curr_obj_name || from || parrent_role 
+                 || with || no_items || in || window 
+		 || window_name || of || app_name)
+	message = g_strconcat (on, curr_obj_role, curr_obj_name, 
+			    from, parrent_role, with, no_items, 
+			    in, window, window_name, of, 
+			    app_name, NULL);
 
     if (message)
 	src_speech_send_chunk (message, SRC_SPEECH_PRIORITY_IDLE, TRUE);
@@ -2119,12 +2186,18 @@ src_surroundings_logic ()
     fprintf (stderr, "\n%s", message); 
 #endif
     g_free (message);
-    g_free (message1);
-    g_free (message2);
-    g_free (message3);
-    g_free (message4);
-    g_free (message5);
-    g_free (message6);
+    g_free (on);
+    g_free (curr_obj_role);
+    g_free (curr_obj_name);
+    g_free (from);
+    g_free (parrent_role);
+    g_free (with);
+    g_free (no_items);
+    g_free (in);
+    g_free (window);
+    g_free (window_name);
+    g_free (of);
+    g_free (app_name);
 
     sro_release_reference (parent);
     g_slist_free (cnt_list);
@@ -2354,10 +2427,16 @@ src_present_line_to_braille_or_brlmon (SRWAccLine *line)
     if (brlout)
     {
 	gchar *tmp;
+	gchar *braille_translation_table = NULL;
 	gchar offset[10];
+	gint braille_offset;
+	
 	tmp = brlout;
-	sprintf (offset, "%d", src_braille_offset);
-	brlout = g_strconcat ("<BRLOUT language=\"", src_braille_translation_table, "\" bstyle=\"8\" clear=\"true\">",
+	braille_translation_table = src_braille_get_translation_table ();
+	braille_offset = src_braille_get_offset ();
+	
+	sprintf (offset, "%d", braille_offset);
+	brlout = g_strconcat ("<BRLOUT language=\"", braille_translation_table, "\" bstyle=\"8\" clear=\"true\">",
 				"<BRLDISP role=\"main\" offset=\"", offset, "\" clear=\"true\">",
 				brlout, "</BRLDISP>",
 				"</BRLOUT>",
@@ -2385,6 +2464,40 @@ src_flat_review_line (gint index)
     int y1 = 0, y2 = 0;
 
     sru_assert (1 <= index && index <= n_lines);
+    
+    if (visited && (index == 1 || index == n_lines))
+    {
+	if (index == 1 && src_use_speech)
+	{
+	    gchar *message;
+	    message = src_xml_make_part ("TEXT", src_speech_get_voice ("system"), _("first line"));
+	    src_speech_send_chunk (message, SRC_SPEECH_PRIORITY_IDLE, TRUE);
+	    g_free (message);
+	}    
+	else if (index == n_lines && src_use_speech)
+	{
+	    gchar *message;
+	    message = src_xml_make_part ("TEXT", src_speech_get_voice ("system"), _("last line"));
+	    src_speech_send_chunk (message, SRC_SPEECH_PRIORITY_IDLE, TRUE);
+	    g_free (message);
+	}
+	
+	if (index == 1 && (src_use_braille || src_use_braille_monitor))
+	{
+	    if (src_use_braille)
+		src_braille_show (_("[first line]"));
+	    if (src_use_braille_monitor)
+		src_brlmon_show (_("[first line]"));
+	}
+	else if (index == n_lines && (src_use_braille || src_use_braille_monitor))
+	{
+	    if (src_use_braille)
+		src_braille_show (_("[last line]"));
+	    if (src_use_braille_monitor)
+		src_brlmon_show (_("[last line]"));
+	}
+	return TRUE;
+    }
 	
     line = screen_review_get_line (index, &y1, &y2);
 	
@@ -2443,6 +2556,11 @@ src_flat_review_line (gint index)
     }
     else if (line && (src_use_braille || src_use_braille_monitor))
 	src_present_line_to_braille_or_brlmon (line);
+	
+    if (index == 1 || index == n_lines)
+	visited = TRUE;
+    else
+	visited = FALSE;		
 
     return TRUE;
 }
@@ -2647,7 +2765,6 @@ src_hierarchy_logic ()
 static gboolean
 src_hierarchy_flat ()
 {
-    gchar *spout;
     gint cnt = 0;
     gint i;
 
@@ -2679,29 +2796,24 @@ src_hierarchy_flat ()
 	    src_ctrl_flat_mode_terminate ();
 	    return FALSE;
 	}
+	
 	flat_review_x = clip_rectangle.x;
     }
-    spout = g_strdup ("");
     for (i = 1; i <= cnt; i++)
     {
 	SRWAccLine *line;
 	int y1, y2;
-	gchar *tmp;
+	gchar *tmp = NULL;
 
 	line = screen_review_get_line (i, &y1, &y2);
-	tmp = NULL;
+
 	if (line)
 	    tmp = src_present_line_for_speech (line);
-	if (tmp)
-	{
-	    gchar *tmp2 = spout;
-	    spout = g_strconcat (spout, tmp, NULL);
-	    g_free (tmp2);
-	}
+	if (tmp && tmp[0])
+	    src_speech_send_chunk (tmp, SRC_SPEECH_PRIORITY_IDLE, FALSE);
+	g_free (tmp);    
     }
-    if (spout[0])
-	src_speech_send_chunk (spout, SRC_SPEECH_PRIORITY_IDLE, TRUE);
-    g_free (spout);
+
     screen_review_terminate ();
 
     return TRUE;
@@ -2748,7 +2860,7 @@ src_ctrl_flat_mode_init ()
 {
     gboolean rv = FALSE;
     
-    src_braille_offset = 0;
+    src_braille_set_offset (0);
     src_tracking_mode = SRC_MODE_FLAT_REVIEW;
     if (src_use_speech)
 	src_say_message (_("flat review mode")); 
@@ -2849,7 +2961,10 @@ static gboolean
 src_braille_scroll_char_left ()
 {
     gboolean old = src_use_speech;
-    src_braille_offset = MAX (0, src_braille_offset - 1);
+    gint offset;
+    
+    offset = src_braille_get_offset ();
+    src_braille_set_offset (MAX (0, offset - 1));
     src_use_speech = FALSE;
     src_cmd_queue_add ("repeat last");
     src_cmd_queue_process ();
@@ -2861,7 +2976,10 @@ static gboolean
 src_braille_scroll_char_right ()
 {
     gboolean old = src_use_speech;
-    src_braille_offset = MIN (1024, src_braille_offset + 1);
+    gint offset;
+    
+    offset = src_braille_get_offset ();
+    src_braille_set_offset (MIN (1024, offset + 1));
     src_use_speech = FALSE;
     src_cmd_queue_add ("repeat last");
     src_cmd_queue_process ();
@@ -2875,7 +2993,10 @@ static gboolean
 src_braille_scroll_display_left ()
 {
     gboolean old = src_use_speech;
-    src_braille_offset = MAX (0, src_braille_offset - 20);
+    gint offset;
+    
+    offset = src_braille_get_offset ();
+    src_braille_set_offset (MAX (0, offset - 20));
     src_use_speech = FALSE;
     src_cmd_queue_add ("repeat last");
     src_cmd_queue_process ();
@@ -2889,7 +3010,10 @@ static gboolean
 src_braille_scroll_display_right ()
 {
     gboolean old = src_use_speech;
-    src_braille_offset = MIN (1024, src_braille_offset + 20);
+    gint offset;
+    
+    offset = src_braille_get_offset ();
+    src_braille_set_offset (MIN (1024, offset + 20));
     src_use_speech = FALSE;
     src_cmd_queue_add ("repeat last");
     src_cmd_queue_process ();
@@ -3013,9 +3137,10 @@ static struct
 
 	{"attributes at caret", 	src_caret_attributes	 	},
 	{"watch current object", 	src_watch_current	 	},
+	{"unwatch all objects", 	src_unwatch_all	 		},
 
 	{"window hierarchy",		src_hierarchy_logic		},
-	{"window hierarchy flat",	src_hierarchy_flat		},
+	{"read whole window",	        src_hierarchy_flat		},
 	{"detailed informations",	src_detailed_informations	},
 	{"do default action",		src_do_default_action		},
 	{"window overview",		src_overview			},
@@ -3474,12 +3599,15 @@ src_ctrl_position_sensor_action_flat (gint index)
 static void
 src_ctrl_position_sensor_action_logic (gint index)
 {
+    gint braille_position_sensor;
+    
     if (!src_crt_sro)
 	return;
 	
     src_text_index = index >= 0 ? index : 0;
 
-    switch (src_braille_position_sensor)
+    braille_position_sensor = src_braille_get_position_sensor ();
+    switch (braille_position_sensor)
     {
 	case 0:
 	    break;
@@ -3548,12 +3676,14 @@ src_ctrl_position_sensor_action_logic (gint index)
 static void
 src_ctrl_optical_sensor_action_logic (gint index)
 {
+    gint braille_optical_sensor;
     if (!src_crt_sro)
 	return;
 
     src_text_index = index >= 0 ? index : 0;
 
-    switch (src_braille_optical_sensor)
+    braille_optical_sensor = src_braille_get_optical_sensor ();
+    switch (braille_optical_sensor)
     {
 	case 0:
 	    break;
