@@ -1525,6 +1525,9 @@ src_process_key_ (gchar *key)
 					 NULL);
 	g_free (tmp);	
     }
+    else if (text_echo_type == SRC_SPEECH_TEXT_ECHO_NONE)
+    {	
+    }
     else
 	sru_assert_not_reached ();
     return TRUE;
@@ -1697,6 +1700,8 @@ src_process_cursor (gchar *cursor)
 	    src_last_cursor_echo = g_strdup (_("backspace"));
 	else if (strcmp (cursor, "Delete") == 0)
 	    src_last_cursor_echo = g_strdup (_("delete"));
+	else if (strcmp (cursor, "Escape") == 0)
+	    src_last_cursor_echo = g_strdup (_("escape"));	    
 	else
 	    sru_assert_not_reached ();
 	        
@@ -1749,7 +1754,8 @@ src_process_key (SREvent *event,
 	     strcmp (srhotkey_data->keystring, "Down") == 0 ||
 	     strcmp (srhotkey_data->keystring, "Up") == 0 ||
 	     strcmp (srhotkey_data->keystring, "BackSpace") == 0 ||
-	     strcmp (srhotkey_data->keystring, "Delete") == 0)
+	     strcmp (srhotkey_data->keystring, "Delete") == 0 ||
+	     strcmp (srhotkey_data->keystring, "Escape") == 0)
     {
 	src_process_cursor (srhotkey_data->keystring);
     }
@@ -2207,7 +2213,8 @@ src_init(const gchar *mouse_tracking,
 	 const gchar *focus_tracking,
 	 const gchar *config_source,
 	 gboolean    invert,
-	 gint 	     zoomfactor)
+	 gint 	     zoomfactor,
+	 gboolean    horiz_split)
 {
     SRLClient client;
     gchar *message = _("Welcome to Gnopernicus");
@@ -2265,15 +2272,20 @@ src_init(const gchar *mouse_tracking,
 		    	    focus_tracking,
 			    invert,
 			    zoomfactor);
-
+			    
+    
     /* initialize Magnifier */
     if (src_use_magnifier)
     {
 	src_use_magnifier = src_magnifier_init ();
 	if (src_use_magnifier)
+	{
 	    src_magnifier_create ();
+	    src_magnifier_set_split_screen_horizontal (horiz_split);
+	}
     }
     
+    
     src_process_change_for_presentation (TRUE);
 
     /* initialize SRLow */
@@ -2414,8 +2426,8 @@ main (gint argc,
 
     gint  	zoom_factor     = 0;
     gboolean 	invert 	    	= FALSE;
-
-    
+    gboolean    horiz_split     = FALSE;
+    gboolean 	login_enabled	= FALSE;    
 
     struct poptOption poptopt[] = 
     {		
@@ -2537,7 +2549,26 @@ main (gint argc,
 	 "Magnification with reverse video", 
 	 ""
 	},
-
+	
+	{
+	"magnification-horizontal-split", 
+	 'u', 
+	 POPT_ARG_NONE, 
+	 &horiz_split, 	
+	 0, 
+	 "Magnification with horizontal-split", 
+	 ""
+	},
+	
+	{
+	"login", 
+	 'l', 
+	 POPT_ARG_NONE, 
+	 &login_enabled, 	
+	 0, 
+	 "Used at login time", 
+	 ""
+	},
 	{
 	"magnification-mouse-tracking", 
 	 't', 
@@ -2608,9 +2639,13 @@ main (gint argc,
 	braille_device = tmp;
     }
     
-     
+    if (login_enabled)
+    {
+	/*To be continued*/
+    }
 
-    src_init (mouse_tracking, focus_tracking, config_source, invert, zoom_factor);
+    src_init (mouse_tracking, focus_tracking, config_source, invert,
+	      zoom_factor, horiz_split);
     	
     g_free (mouse_tracking);
     g_free (focus_tracking);
