@@ -753,83 +753,83 @@ static struct
     gchar 	*speech_short;
 }src_presentation_role_pres[] =
     {
-	{"unknown",			"UNK",	"UNKNOWN",		"Unknown",		},
-	{"invalid",			"???",	"INVALID",		"Invalid", 		},
-        {"alert", 			"ALR",	"ALERT",		"Alert",		},
-	{"canvas",			"CNV",	"CANVAS",		"Canvas",		},
-        {"check-box",			"CHK",	"CHECK_BOX",		"Check box",		},
-	{"check-menu-item",		"MIT",	"MENU ITEM",		"Check Menu item",	},
-	{"color-chooser",		"CCH",	"COLOR CHOOSER",	"Color chooser",	},
-        {"column-header",		"CHD",	"COLUMN HEADER",	"Column header",	},
-	{"combo-box",			"CBO",	"COMBO BOX",		"Combo box",		},
-        {"desktop-icon",		"DIC",	"DESKTOP ICON",		"Desktop icon",		},
-	{"desktop-frame",		"DFR",	"DESKTOP FRAME",	"Desktop frame",	},
-        {"dialog",			"DLG",	"DIALOG",		"Dialog",		},
-	{"directory-pane",		"DIP",	"DIRECTORY PANE",	"Directory pane",	},
-        {"file-chooser",		"FCH",	"FILE CHOOSER",		"File chooser",		},
-	{"filler",			"FLR",	"FILLER",		"Filler",		},
-        {"frame",			"FRM",	"FRAME",		"Frame",		},
-        {"glass-pane",			"GPN",	"GLASS PANE",		"Glass pane",		},
-	{"HTML-container",		"HTM",	"HTML CONTAINER",	"H T M L container",	},
-	{"hyper link",			"LNK",	"LINK",			"link",		},
-        {"icon",			"ICO",	"ICON",			"Icon",			},
-        {"internal-frame",		"IFR",	"INTERNAL FRAME",	"Internal frame",	},
-	{"label",			"LBL",	"LABEL",		"Label",		},
-        {"layered-pane",		"LPN",	"LAYERED PANE",		"Layered pane",		},
-	{"link",			"LNK",	"LINK",			"link",			},
-	{"list",			"LST",	"LIST",			"List",			},
-        {"list-item",			"LIT",	"LIST ITEM",		"List item",		},
-	{"menu",			"MNU",	"MENU",			"Menu",			},
-        {"menu-bar",			"MBR",	"MENU BAR",		"Menu bar",		},
-	{"menu-item",			"MIT",	"MENU ITEM",		"Menu item",		},
-        {"option-pane",			"OPN",	"OPTION PANE",		"Option pane",		},
-        {"page-tab",			"PGT",	"PAGE TAB",		"Page tab",		},
-	{"page-tab-list",		"PTL",	"PAGE TAB LIST",	"Page tab list",	},
-        {"panel",			"PNL",	"PANEL",		"Panel",		},
-        {"password-text",		"PWD",	"PASSWORD TEXT",	"Password text",	},
-	{"popup-menu",			"PMN",	"POPUP MENU",		"Popup menu",		},
-        {"progress-bar",		"PRG",	"PROGRESS BAR",		"Progress bar",		},
-	{"push-button",			"PBT",	"PUSH BUTTON",		"Push button",		},
-        {"radio-button",		"RAD",	"RADIO BUTTON",		"Radio button",		},
-	{"radio-menu-item",		"MIT",	"MENU ITEM",		"Radio Menu item",	},
-        {"root-pane",			"RPN",	"ROOT PANE",		"Root pane",		},
-	{"row-header",			"RHD",	"ROW HEADER",		"Row header",		},
-        {"scroll-bar",			"SCR",	"SCROLL BAR",		"Scroll bar",		},
-	{"scroll-pane",			"SPN",	"SCROLL PANE",		"Scroll pane",		},
-        {"separator",			"SEP",	"SEPARATOR",		"Separator",		},
-	{"slider",			"SLD",	"SLIDER",		"Slider",		},
-        {"split-pane",			"SPP",	"SPLIT PANE",		"Split pane",		},
-	{"status-bar",			"STA",	"STATUS BAR",		"Status bar",		},
-        {"table",			"TAB",	"TABLE",		"Table",		},
-	{"table-cell",			"CEL",	"TABLE CELL",		"Table cell",		},
-        {"table-column-header",		"TCH",	"TABLE COLUMN HEADER",	"Table column header",	},
-	{"table-row-header",		"TRH",	"TABLE ROW HEADER",	"Table row header",	},
-        {"multi-line-text",		"TXT",	"MULTI LINE TEXT",	"Multi Line Text",	},
-        {"single-line-text",		"TXT",	"SINGLE LINE TEXT",	"Single Line Text",	},
-	{"toggle-button",		"TOG",	"TOGGLE BUTTON",	"Toggle button",	},
-        {"tool-bar",			"TOL",	"TOOL BAR",		"Tool bar",		},
-	{"tool-tip",			"TIP",	"TOOL TIP",		"Tool tip",		},
-        {"tree",			"TRE",	"TREE",			"Tree",			},
-        {"tree-item",			"TRI",	"TREE ITEM",		"Tree item",		},
-	{"tree-table",			"TRT",	"TREE TABLE",		"Tree table",		},
-	{"viewport",			"VWP",	"VIEWPORT",		"Viewport",		},
-	{"window",			"WND",	"WINDOW",		"Window",		},
-	{"accelerator-label",		"ACC",	"ACCELERATOR LABEL",	"Accelerator label",	},
-        {"animation",			"ANI",	"ANIMATION",		"Animation",		},
-	{"arrow",			"ARR",	"ARROW",		"Arrow",		},
-        {"calendar",			"CAL",	"CALENDAR",		"Calendar",		},
-	{"date-editor",			"DAT",	"DATE EDITOR",		"Date editor",		},
-        {"dial",			"DIL",	"DIAL",			"Dial",			},
-	{"drawing-area",		"DRW",	"DRAWING AREA",		"Drawing area",		},
-        {"font-chooser",		"FNT",	"FONT CHOOSER",		"Font chooser",		},
-	{"image",			"IMG",	"IMAGE",		"Image",		},
-        {"spin-button",			"SPN",	"SPIN BUTTON",		"Spin button",		},
-	{"terminal",			"TRM",	"TERMINAL",		"Terminal",		},
-        {"extended",			"EXT",	"EXTENDED",		"Extended",		},
-	{"table-line",			"TLI",	"TABLE LINE",		"Table line",		},
-        {"table-columns-header",	"TCH","TABLE COLUMNS HEADER",	"Table columns header",	},
-	{"title-bar",			"TIT",	"TITLE BAR",		"Title bar",		},
-	{"edit-bar",			"EDB",	"EDIT BAR",		"Edit bar",		}
+	{"unknown",		N_("UNK"),	N_("UNKNOWN"),		N_("Unknown")			},
+	{"invalid",		N_("???"),	N_("INVALID"),		N_("Invalid")			},
+	{"alert",		N_("ALR"),	N_("ALERT"),		N_("Alert")			},
+	{"canvas",		N_("CNV"),	N_("CANVAS"),		N_("Canvas")			},
+	{"check-box",		N_("CHK"),	N_("CHECK_BOX"),	N_("Check box")			},
+	{"check-menu-item",	N_("MIT"),	N_("MENU ITEM"),	N_("Check Menu item")		},
+	{"color-chooser",	N_("CCH"),	N_("COLOR CHOOSER"),	N_("Color chooser")		},
+	{"column-header",	N_("CHD"),	N_("COLUMN HEADER"),	N_("Column header")		},
+	{"combo-box",		N_("CBO"),	N_("COMBO BOX"),	N_("Combo box")			},
+	{"desktop-icon",	N_("DIC"),	N_("DESKTOP ICON"),	N_("Desktop icon")		},
+	{"desktop-frame",	N_("DFR"),	N_("DESKTOP FRAME"),	N_("Desktop frame")		},
+	{"dialog",		N_("DLG"),	N_("DIALOG"),		N_("Dialog")			},
+	{"directory-pane",	N_("DIP"),	N_("DIRECTORY PANE"),	N_("Directory pane")		},
+	{"file-chooser",	N_("FCH"),	N_("FILE CHOOSER"),	N_("File chooser")		},
+	{"filler",		N_("FLR"),	N_("FILLER"),		N_("Filler")			},
+	{"frame",		N_("FRM"),	N_("FRAME"),		N_("Frame")			},
+	{"glass-pane",		N_("GPN"),	N_("GLASS PANE"),	N_("Glass pane")		},
+	{"HTML-container",	N_("HTM"),	N_("HTML CONTAINER"),	N_("H T M L container")		},
+	{"hyper link",		N_("LNK"),	N_("LINK"),		N_("link")			},
+	{"icon",		N_("ICO"),	N_("ICON"),		N_("Icon")			},
+	{"internal-frame",	N_("IFR"),	N_("INTERNAL FRAME"),	N_("Internal frame")		},
+	{"label",		N_("LBL"),	N_("LABEL"),		N_("Label")			},
+	{"layered-pane",	N_("LPN"),	N_("LAYERED PANE"),	N_("Layered pane")		},
+	{"link",		N_("LNK"),	N_("LINK"),		N_("link")			},
+	{"list",		N_("LST"),	N_("LIST"),		N_("List")			},
+	{"list-item",		N_("LIT"),	N_("LIST ITEM"),	N_("List item")			},
+	{"menu",		N_("MNU"),	N_("MENU"),		N_("Menu")			},
+	{"menu-bar",		N_("MBR"),	N_("MENU BAR"),		N_("Menu bar")			},
+	{"menu-item",		N_("MIT"),	N_("MENU ITEM"),	N_("Menu item")			},
+	{"option-pane",		N_("OPN"),	N_("OPTION PANE"),	N_("Option pane")		},
+	{"page-tab",		N_("PGT"),	N_("PAGE TAB"),		N_("Page tab")			},
+	{"page-tab-list",	N_("PTL"),	N_("PAGE TAB LIST"),	N_("Page tab list")		},
+	{"panel",		N_("PNL"),	N_("PANEL"),		N_("Panel")			},
+	{"password-text",	N_("PWD"),	N_("PASSWORD TEXT"),	N_("Password text")		},
+	{"popup-menu",		N_("PMN"),	N_("POPUP MENU"),	N_("Popup menu")		},
+	{"progress-bar",	N_("PRG"),	N_("PROGRESS BAR"),	N_("Progress bar")		},
+	{"push-button",		N_("PBT"),	N_("PUSH BUTTON"),	N_("Push button")		},
+	{"radio-button",	N_("RAD"),	N_("RADIO BUTTON"),	N_("Radio button")		},
+	{"radio-menu-item",	N_("MIT"),	N_("MENU ITEM"),	N_("Radio Menu item")		},
+	{"root-pane",		N_("RPN"),	N_("ROOT PANE"),	N_("Root pane")			},
+	{"row-header",		N_("RHD"),	N_("ROW HEADER"),	N_("Row header")		},
+	{"scroll-bar",		N_("SCR"),	N_("SCROLL BAR"),	N_("Scroll bar")		},
+	{"scroll-pane",		N_("SPN"),	N_("SCROLL PANE"),	N_("Scroll pane")		},
+	{"separator",		N_("SEP"),	N_("SEPARATOR"),	N_("Separator")			},
+	{"slider",		N_("SLD"),	N_("SLIDER"),		N_("Slider")			},
+	{"split-pane",		N_("SPP"),	N_("SPLIT PANE"),	N_("Split pane")		},
+	{"status-bar",		N_("STA"),	N_("STATUS BAR"),	N_("Status bar")		},
+	{"table",		N_("TAB"),	N_("TABLE"),		N_("Table")			},
+	{"table-cell",		N_("CEL"),	N_("TABLE CELL"),	N_("Table cell")		},
+	{"table-column-header",	N_("TCH"),	N_("TABLE COLUMN HEADER"),N_("Table column header")	},
+	{"table-row-header",	N_("TRH"),	N_("TABLE ROW HEADER"),	N_("Table row header")		},
+	{"multi-line-text",	N_("TXT"),	N_("MULTI LINE TEXT"),	N_("Multi Line Text")		},
+	{"single-line-text",	N_("TXT"),	N_("SINGLE LINE TEXT"),	N_("Single Line Text")		},
+	{"toggle-button",	N_("TOG"),	N_("TOGGLE BUTTON"),	N_("Toggle button")		},
+	{"tool-bar",		N_("TOL"),	N_("TOOL BAR"),		N_("Tool bar")			},
+	{"tool-tip",		N_("TIP"),	N_("TOOL TIP"),		N_("Tool tip")			},
+	{"tree",		N_("TRE"),	N_("TREE"),		N_("Tree")			},
+	{"tree-item",		N_("TRI"),	N_("TREE ITEM"),	N_("Tree item")			},
+	{"tree-table",		N_("TRT"),	N_("TREE TABLE"),	N_("Tree table")		},
+	{"viewport",		N_("VWP"),	N_("VIEWPORT"),		N_("Viewport")			},
+	{"window",		N_("WND"),	N_("WINDOW"),		N_("Window")			},
+	{"accelerator-label",	N_("ACC"),	N_("ACCELERATOR LABEL"),N_("Accelerator label")		},
+	{"animation",		N_("ANI"),	N_("ANIMATION"),	N_("Animation")			},
+	{"arrow",		N_("ARR"),	N_("ARROW"),		N_("Arrow")			},
+	{"calendar",		N_("CAL"),	N_("CALENDAR"),		N_("Calendar")			},
+	{"date-editor",		N_("DAT"),	N_("DATE EDITOR"),	N_("Date editor")		},
+	{"dial",		N_("DIL"),	N_("DIAL"),		N_("Dial")			},
+	{"drawing-area",	N_("DRW"),	N_("DRAWING AREA"),	N_("Drawing area")		},
+	{"font-chooser",	N_("FNT"),	N_("FONT CHOOSER"),	N_("Font chooser")		},
+	{"image",		N_("IMG"),	N_("IMAGE"),		N_("Image")			},
+	{"spin-button",		N_("SPN"),	N_("SPIN BUTTON"),	N_("Spin button")		},
+	{"terminal",		N_("TRM"),	N_("TERMINAL"),		N_("Terminal")			},
+	{"extended",		N_("EXT"),	N_("EXTENDED"),		N_("Extended")			},
+	{"table-line",		N_("TLI"),	N_("TABLE LINE"),	N_("Table line")		},
+	{"table-columns-header",N_("TCH"),	N_("TABLE COLUMNS HEADER"),N_("Table columns header")	},
+	{"title-bar",		N_("TIT"),	N_("TITLE BAR"),	N_("Title bar")			},
+	{"edit-bar",		N_("EDB"),	N_("EDIT BAR"),		N_("Edit bar")			}
     };
 
 static gint
@@ -858,7 +858,7 @@ src_presentation_get_role_name_for_braille (const gchar *role)
     index = src_presentation_get_role_index (role);
 
     if (index)
-    return src_presentation_role_pres[index].braille_short;
+	return _(src_presentation_role_pres[index].braille_short);
     else
 	return role;
 }
@@ -873,7 +873,7 @@ src_presentation_get_role_name_for_speech (const gchar *role)
     index = src_presentation_get_role_index (role);
 
     if (index)
-    return src_presentation_role_pres[index].speech_short;
+	return _(src_presentation_role_pres[index].speech_short);
     else
 	return role;
 }
@@ -1489,5 +1489,8 @@ src_pres_get_role_name_for_speech (const gchar *role)
 
     index = src_presentation_get_role_index (role);
 
-    return src_presentation_role_pres[index].speech_short;
+    if (index)
+	return _(src_presentation_role_pres[index].speech_short);
+    else
+	return role;
 }
