@@ -52,7 +52,8 @@ typedef enum
 typedef enum
 {
     SRC_SPEECH_TEXT_ECHO_CHAR,
-    SRC_SPEECH_TEXT_ECHO_WORD
+    SRC_SPEECH_TEXT_ECHO_WORD,
+    SRC_SPEECH_TEXT_ECHO_NONE
 }SRCSpeechTextEchoType;
 
 typedef enum
@@ -123,6 +124,12 @@ gchar*   src_speech_get_voice 	(gchar *voice);
 gboolean src_speech_say		(gchar *message, gboolean shutup);
 gchar*   src_process_string 	(const gchar *str, SRCSpeechCountMode cmode,
 						    SRCSpeechSpellingMode smode);
+						    
+SRCSpeechTextEchoType 		src_speech_get_text_echo_type 	   ();
+SRCSpeechSpacesEchoType		src_speech_get_spaces_echo_type    ();
+SRCSpeechModifiersEchoType	src_speech_get_modifiers_echo_type ();
+SRCSpeechCursorsEchoType	src_speech_get_cursors_echo_type   ();
+
 /*FIXME end */
 
 #endif /* _SRSPC_H_ */
