@@ -695,7 +695,7 @@ void SRTest_print_obj (SRObject *sr_obj, char *msg)
 		    fprintf (stderr, "\n\t\t\t  Sentence attr : %s", val);
 		    SR_freeString (val);
 		    sra_get_attribute_values_string (attr[i], "bold:size", &val);
-		    fprintf (stderr, "\n\t\t\t  Sentence attr value for bold and size : %s", val);
+		    fprintf (stderr, "\n\t\t\t  Sentence attr value for bold and size : %s", val ? val : "(none)");
 		    SR_freeString (val);
 		    sra_get_attribute_value (attr[i], "font-name", &val);
 		    fprintf (stderr, "\n\t\t\t  Sentence attr value for font-name : %s", val ? val : "(none)");
