@@ -1,4 +1,4 @@
-/* SREvent.h
+/* srintl.h
  *
  * Copyright 2001, 2002 Sun Microsystems, Inc.,
  * Copyright 2001, 2002 BAUM Retec, A.G.
@@ -25,24 +25,8 @@
 #include "config.h"
 #include "libgnome/libgnome.h"
 
-#if 0
-#ifdef ENABLE_NLS
-#include<libintl.h>
-#define _(String) dgettext(GETTEXT_PACKAGE,String)
-#ifdef gettext_noop
-#define N_(String) gettext_noop(String)
-#else
-#define N_(String) (String)
-#endif
-#else /* NLS is disabled */
-#define _(String) (String)
-#define N_(String) (String)
-#define textdomain(String) (String)
-#define gettext(String) (String)
-#define dgettext(Domain,String) (String)
-#define dcgettext(Domain,String,Type) (String)
-#define bindtextdomain(Domain,Directory) (Domain) 
+#ifndef ENABLE_NLS
+#define ngettext(x, y, z) ((z) == 1 ? (x) : (y))
 #endif
 
 #endif
-#endif
